import { MastraBase } from './chunk-TGPURYN5.js';
import { experimental_customProvider } from 'ai';
import node_modulesPath from 'node_modules-path';
import path from 'path';

var cachedPath = false;
function getModelCachePath() {
  if (cachedPath) return cachedPath;
  const firstNodeModules = node_modulesPath().split("node_modules")[0];
  cachedPath = path.join(firstNodeModules, "node_modules", ".fastembed-model-cache");
  return cachedPath;
}
var fastEmbedImportPath = "fastembed?" + Date.now();
async function generateEmbeddings(values, modelType) {
  try {
    const { EmbeddingModel, FlagEmbedding } = await import(fastEmbedImportPath);
    const model = await FlagEmbedding.init({
      model: EmbeddingModel[modelType],
      cacheDir: getModelCachePath()
    });
    const embeddings = await model.embed(values);
    const allResults = [];
    for await (const result of embeddings) {
      allResults.push(...result.map((embedding) => Array.from(embedding)));
    }
    if (allResults.length === 0) throw new Error("No embeddings generated");
    return {
      embeddings: allResults
    };
  } catch (error) {
    console.error("Error generating embeddings:", error);
    throw error;
  }
}
var fastEmbedProvider = experimental_customProvider({
  textEmbeddingModels: {
    "bge-small-en-v1.5": {
      specificationVersion: "v1",
      provider: "fastembed",
      modelId: "bge-small-en-v1.5",
      maxEmbeddingsPerCall: 256,
      supportsParallelCalls: true,
      async doEmbed({ values }) {
        return generateEmbeddings(values, "BGESmallENV15");
      }
    },
    "bge-base-en-v1.5": {
      specificationVersion: "v1",
      provider: "fastembed",
      modelId: "bge-base-en-v1.5",
      maxEmbeddingsPerCall: 256,
      supportsParallelCalls: true,
      async doEmbed({ values }) {
        return generateEmbeddings(values, "BGEBaseENV15");
      }
    }
  }
});
var localEmbedder = fastEmbedProvider.textEmbeddingModel;

// src/vector/index.ts
var MastraVector = class extends MastraBase {
  constructor() {
    super({ name: "MastraVector", component: "VECTOR" });
  }
};

export { MastraVector, localEmbedder };
