import { RegisteredLogger, createLogger } from './chunk-O2VP5JBC.js';

// src/base.ts
var MastraBase = class {
  component = RegisteredLogger.LLM;
  logger;
  name;
  telemetry;
  constructor({ component, name }) {
    this.component = component || RegisteredLogger.LLM;
    this.name = name;
    this.logger = createLogger({ name: `${this.component} - ${this.name}` });
  }
  /**
   * Set the logger for the agent
   * @param logger
   */
  __setLogger(logger) {
    this.logger = logger;
    this.logger.debug(`Logger updated for ${this.component}:${this.name}`);
  }
  /**
   * Internal logging helper that formats and sends logs to the configured logger
   * @param level - Severity level of the log
   * @param message - Main log message
   * @param opts - Optional object for the log
   */
  log(level, message, opts) {
    if (!this.logger) return;
    const logMessage = {
      type: this.component,
      message,
      destinationPath: this.name ? `${this.component}/${this.name}` : this.component,
      ...opts || {}
    };
    const logMethod = level.toLowerCase();
    this.logger[logMethod]?.(logMessage);
  }
  /**
   * Set the telemetry for the
   * @param telemetry
   */
  __setTelemetry(telemetry) {
    this.telemetry = telemetry;
    this.logger.debug(`Telemetry updated for ${this.component} ${this.telemetry.tracer}`);
  }
  /**
   * Get the telemetry on the vector
   * @returns telemetry
   */
  __getTelemetry() {
    return this.telemetry;
  }
  /* 
    get experimental_telemetry config
    */
  get experimental_telemetry() {
    return this.telemetry ? {
      tracer: this.telemetry.tracer,
      isEnabled: !!this.telemetry.tracer
    } : undefined;
  }
};

export { MastraBase };
