import { A as Agent, M as MastraStorage, a as MastraMemory } from '../index-Cwb-5AzX.js';
import { L as Logger, B as BaseLogMessage } from '../index-CBZ2mk2H.js';
import { W as Workflow } from '../workflow-DTtv7_Eq.js';
import { MastraVector } from '../vector/index.js';
import { O as OtelConfig, T as Telemetry } from '../telemetry-oCUM52DG.js';
import { MastraTTS } from '../tts/index.js';
import { MastraDeployer } from '../deployer/index.js';
import 'ai';
import 'json-schema';
import 'zod';
import '../base.js';
import '@opentelemetry/api';
import '../metric-BWeQNZt6.js';
import 'sift';
import 'pino';
import 'stream';
import 'xstate';
import '@opentelemetry/sdk-node';
import '@opentelemetry/sdk-trace-base';
import '../bundler/index.js';

declare class Mastra<TAgents extends Record<string, Agent<any>> = Record<string, Agent<any>>, TWorkflows extends Record<string, Workflow> = Record<string, Workflow>, TVectors extends Record<string, MastraVector> = Record<string, MastraVector>, TTTS extends Record<string, MastraTTS> = Record<string, MastraTTS>, TLogger extends Logger = Logger> {
    private vectors?;
    private agents;
    private logger;
    private workflows;
    private telemetry?;
    private tts?;
    private deployer?;
    storage?: MastraStorage;
    memory?: MastraMemory;
    constructor(config?: {
        memory?: MastraMemory;
        agents?: TAgents;
        storage?: MastraStorage;
        vectors?: TVectors;
        logger?: TLogger | false;
        workflows?: TWorkflows;
        tts?: TTTS;
        telemetry?: OtelConfig;
        deployer?: MastraDeployer;
    });
    getAgent<TAgentName extends keyof TAgents>(name: TAgentName): TAgents[TAgentName];
    getAgents(): TAgents;
    getVector<TVectorName extends keyof TVectors>(name: TVectorName): TVectors[TVectorName];
    getVectors(): TVectors | undefined;
    getDeployer(): MastraDeployer | undefined;
    getWorkflow<TWorkflowId extends keyof TWorkflows>(id: TWorkflowId, { serialized }?: {
        serialized?: boolean;
    }): TWorkflows[TWorkflowId];
    getWorkflows(props?: {
        serialized?: boolean;
    }): Record<string, Workflow>;
    setStorage(storage: MastraStorage): void;
    setLogger({ logger }: {
        logger: TLogger;
    }): void;
    getLogger(): TLogger;
    getTelemetry(): Telemetry | undefined;
    getLogsByRunId({ runId, transportId }: {
        runId: string;
        transportId: string;
    }): Promise<BaseLogMessage[] | undefined>;
    getLogs(transportId: string): Promise<BaseLogMessage[]>;
}

export { Mastra };
