import { M as MastraStorage, k as TABLE_NAMES, l as StorageColumn, N as StorageThreadType, K as MessageType, n as StorageGetMessagesArg, E as EvalRow } from '../index-Cwb-5AzX.js';
export { m as WorkflowRow } from '../index-Cwb-5AzX.js';
import '../telemetry-oCUM52DG.js';
export { LibSQLVector as DefaultVectorDB, LibSQLVector } from '../vector/libsql/index.js';
import 'ai';
import 'json-schema';
import 'zod';
import '../base.js';
import '@opentelemetry/api';
import '../index-CBZ2mk2H.js';
import 'pino';
import 'stream';
import '@opentelemetry/sdk-node';
import '@opentelemetry/sdk-trace-base';
import '../metric-BWeQNZt6.js';
import 'sift';
import '../vector/index.js';
import '../tts/index.js';
import '../filter/index.js';

interface LibSQLConfig {
    url: string;
    authToken?: string;
}
declare class DefaultStorage extends MastraStorage {
    private client;
    constructor({ config }: {
        config: LibSQLConfig;
    });
    protected rewriteDbUrl(url: string): string;
    private getCreateTableSQL;
    createTable({ tableName, schema, }: {
        tableName: TABLE_NAMES;
        schema: Record<string, StorageColumn>;
    }): Promise<void>;
    clearTable({ tableName }: {
        tableName: TABLE_NAMES;
    }): Promise<void>;
    insert({ tableName, record }: {
        tableName: TABLE_NAMES;
        record: Record<string, any>;
    }): Promise<void>;
    load<R>({ tableName, keys }: {
        tableName: TABLE_NAMES;
        keys: Record<string, string>;
    }): Promise<R | null>;
    getThreadById({ threadId }: {
        threadId: string;
    }): Promise<StorageThreadType | null>;
    getThreadsByResourceId({ resourceId }: {
        resourceId: string;
    }): Promise<StorageThreadType[]>;
    saveThread({ thread }: {
        thread: StorageThreadType;
    }): Promise<StorageThreadType>;
    updateThread({ id, title, metadata, }: {
        id: string;
        title: string;
        metadata: Record<string, unknown>;
    }): Promise<StorageThreadType>;
    deleteThread({ threadId }: {
        threadId: string;
    }): Promise<void>;
    private parseRow;
    getMessages<T extends MessageType[]>({ threadId, selectBy }: StorageGetMessagesArg): Promise<T>;
    saveMessages({ messages }: {
        messages: MessageType[];
    }): Promise<MessageType[]>;
    getEvalsByAgentName(agentName: string, type?: 'test' | 'live'): Promise<EvalRow[]>;
}

export { DefaultStorage, EvalRow, type LibSQLConfig, MastraStorage, DefaultStorage as MastraStorageLibSql, StorageColumn, StorageGetMessagesArg, TABLE_NAMES };
